# sync2jira

## Importer le package
```
 pip install synchros1s2
```

## Mettre à jour le package 
⚠️ A faire 2 fois !! 
```
 pip install --upgrade synchros1s2
 pip install --upgrade synchros1s2
```

## Remplir le fichier de config 
Pour remplir les différents paramétres du fichier de config
1. from config.config_package import config_package 
2. config_package()





